#!/bin/sh
#
# Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
#
# Contact: Marcell Lengyel <marcell.lengyel@nokia.com>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public License
# version 2.1 as published by the Free Software Foundation.
#
# This library is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
# 02110-1301 USA
#

set -u
#exec 2>> /tmp/developer-mode-sh.log; date >&2; pwd >&2; set -x; : ::: "$@"

LC_ALL=C LANG=C
PATH=/bin:/sbin:/usr/bin:/usr/sbin
export LC_ALL LANG PATH

libdir=/usr/lib/developer-mode
helper=$libdir/bin/devmodehelper

die () { echo "$@" >&2; exit 1; }

master_pkgs='sdk-connectivity-tool meego-terminal'
enable_master ()
{
	gconftool -s /Meego/System/DeveloperMode --type=string true
	test -f /etc/developer-mode.conf ||
		mv -f /etc/developer-mode.disabled /etc/developer-mode.conf
	touch /etc/developer-mode.conf # XXX remove mad-developer dependency...
	$helper syslog enable
	$helper desktop_files_enable $master_pkgs
	/usr/lib/mad-developer/mode.sh enable
}
disable_master ()
{
	gconftool -s /Meego/System/DeveloperMode --type=string false
	/usr/lib/mad-developer/mode.sh disable
	$helper desktop_files_disable $master_pkgs
	mv -f /etc/developer-mode.conf /etc/developer-mode.disabled
	$helper syslog disable
	pkill -9 x11vnc
	pkill -9 meego-terminal
	pkill -9 sdk-connectivity-tool
}

sshd=/usr/sbin/sshd

enable_ssh ()
{
	$helper sshd enable
	/sbin/initctl start ssh
}

disable_ssh ()
{
	/sbin/initctl stop ssh
	$helper sshd disable
	pkill -9 sshd
}

enable_energy_profiler () { $helper desktop_files_enable energy-profiler; }
disable_energy_profiler () { $helper desktop_files_disable energy-profiler; }

enable_tctswitch () { $helper desktop_files_enable tctswitch; }
disable_tctswitch () { $helper desktop_files_disable tctswitch; }


# In the xpkgs package list, all '-':s are replaced with '_'.
xpkgs='ssh energy_profiler tctswitch'

enable ()
{
#	case ${DPKG_MAINTSCRIPT_PACKAGE-} in '') test -x /bin/develsh ||
#		/usr/bin/pkgmgr install-file -f $libdir/develsh.deb || :
#	esac

	case $1 in '')	enable_master ;; esac

	for p in $xpkgs
	do case $1 in ''|$p) enable_$p ;; esac
	done
}

disable ()
{
	for p in $xpkgs
	do case $1 in ''|$p) disable_$p ;; esac
	done

	case $1 in '')	disable_master ;; esac
}

case ${1-} in
	enable) enable "${2-}" ;;
	disable) disable "${2-}" ;;
	*) die Usage: $0 '(enable|disable)' '[pkg]' ;;
esac
exit

Local variables:
mode: shell-script
sh-basic-offset: 8
tab-width: 8
End:
vi: set sw=8 ts=8
